var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { RunInstancesCommand, waitUntilInstanceRunning, } from '@aws-sdk/client-ec2';
import { retry } from '#src/common/retry.js';
import { handleWaiterError } from '../common/waiter-error.js';
import { COMMON_WAITER_CONFIG } from '../common/waiter-config.js';
import { createIamInstanceProfileCurrentRegion } from '../iam/create-instance-profile.js';
import { toTagSpecification } from '../tags/utils/to-tag-specification.js';
import { AwsInstanceProfileNotFoundError } from './ec2-errors.js';
import { parseEc2InstanceResponse } from './parse-ec2-response.js';
import { ec2Client } from './ec2-client.js';
export function createEc2Instance({ imageId, name, instanceType, roleNames, profilePathPrefix, subnetId, assignPublicIp, securityGroupIds, userData, requireIMDSv2, instanceTags, tags, }) {
    return __awaiter(this, void 0, void 0, function* () {
        const tagsWithName = [...tags, { key: 'Name', value: name }];
        const instanceProfile = yield createIamInstanceProfileCurrentRegion({
            name,
            roleNames,
            pathPrefix: profilePathPrefix,
            tags,
        });
        const { Instances } = yield retry(() => __awaiter(this, void 0, void 0, function* () {
            return yield ec2Client.send(new RunInstancesCommand({
                BlockDeviceMappings: [
                    {
                        DeviceName: '/dev/xvda',
                        Ebs: {
                            Encrypted: true,
                        },
                    },
                ],
                ImageId: imageId,
                InstanceType: instanceType,
                IamInstanceProfile: {
                    Name: instanceProfile.name,
                },
                NetworkInterfaces: [
                    {
                        DeviceIndex: 0,
                        AssociatePublicIpAddress: assignPublicIp,
                        Groups: securityGroupIds,
                        SubnetId: subnetId,
                    },
                ],
                UserData: userData !== undefined
                    ? Buffer.from(userData).toString('base64')
                    : undefined,
                MetadataOptions: {
                    HttpTokens: requireIMDSv2 === true ? 'required' : 'optional',
                },
                TagSpecifications: [
                    toTagSpecification('instance', [...tagsWithName, ...instanceTags]),
                    toTagSpecification('volume', tagsWithName),
                    toTagSpecification('network-interface', tagsWithName),
                ],
                MinCount: 1,
                MaxCount: 1,
            }));
        }), {
            delay: 3000,
            maxRetries: 10,
            shouldRetry: isInstanceProfileNotFoundError,
        });
        if (Instances === undefined || Instances[0] === undefined) {
            throw new Error(`Invalid response from AWS.`);
        }
        const instance = parseEc2InstanceResponse(Instances[0]);
        yield handleWaiterError(() => __awaiter(this, void 0, void 0, function* () {
            return yield waitUntilInstanceRunning(Object.assign(Object.assign({}, COMMON_WAITER_CONFIG), { client: ec2Client.client }), { InstanceIds: [instance.id] });
        }));
        return instance;
    });
}
function isInstanceProfileNotFoundError(error) {
    return error instanceof AwsInstanceProfileNotFoundError;
}
//# sourceMappingURL=create-ec2-instance.js.map