var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { DescribeSecurityGroupsCommand } from '@aws-sdk/client-ec2';
import { getTagFilter } from '../tags/get-tag-filter.js';
import { ec2Client } from './ec2-client.js';
import { parseSecurityGroupResponse } from './parse-ec2-response.js';
export function getSecurityGroups({ securityGroupIds, tags, names, }) {
    return __awaiter(this, void 0, void 0, function* () {
        if ((securityGroupIds === null || securityGroupIds === void 0 ? void 0 : securityGroupIds.length) === 0) {
            return [];
        }
        const filters = [
            ...(tags ? tags.map(tag => getTagFilter(tag)) : []),
            ...(names ? [getNamesFilter(names)] : []),
        ];
        const { SecurityGroups } = yield ec2Client.send(new DescribeSecurityGroupsCommand({
            GroupIds: securityGroupIds,
            Filters: filters.length > 0 ? filters : undefined,
        }));
        if (!SecurityGroups) {
            throw new Error(`Invalid response from AWS.`);
        }
        return SecurityGroups.map(group => parseSecurityGroupResponse(group));
    });
}
function getNamesFilter(names) {
    return {
        Name: 'group-name',
        Values: names,
    };
}
//# sourceMappingURL=get-security-groups.js.map