var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { DescribeCacheClustersCommand } from '@aws-sdk/client-elasticache';
import { parseMemcachedCacheClusteWithSpecificNoderResponse, parseMemcachedCacheClusterResponse, } from './parse-elasticache-memcached-response.js';
import { elasticacheClient } from './elasticache-client.js';
export function getMemcachedClusters() {
    return __awaiter(this, void 0, void 0, function* () {
        const memcachedClusters = yield getRawMemcachedClusters();
        return memcachedClusters.map(cacheCluster => {
            return parseMemcachedCacheClusterResponse(cacheCluster);
        });
    });
}
export function getRawMemcachedClusters() {
    return __awaiter(this, void 0, void 0, function* () {
        const { CacheClusters } = yield elasticacheClient.send(new DescribeCacheClustersCommand({
            ShowCacheNodeInfo: true,
            ShowCacheClustersNotInReplicationGroups: true,
        }));
        if (!CacheClusters) {
            throw new Error(`Invalid response from AWS.`);
        }
        const memcachedClusters = CacheClusters.filter(cacheCluster => cacheCluster.Engine === 'memcached');
        return memcachedClusters;
    });
}
export function getMemcachedCluster(identifier) {
    return __awaiter(this, void 0, void 0, function* () {
        const { CacheClusters } = yield elasticacheClient.send(new DescribeCacheClustersCommand({
            ShowCacheNodeInfo: true,
            ShowCacheClustersNotInReplicationGroups: true,
            CacheClusterId: identifier,
        }));
        if (!CacheClusters) {
            throw new Error(`Invalid response from AWS.`);
        }
        return parseMemcachedCacheClusterResponse(CacheClusters[0]);
    });
}
export function getMemcachedNode(identifier) {
    return __awaiter(this, void 0, void 0, function* () {
        const cacheClusters = yield getRawMemcachedClusters();
        const cluster = cacheClusters.find(cluster => cluster.CacheNodes.some(node => { var _a; return ((_a = cluster.CacheClusterId) === null || _a === void 0 ? void 0 : _a.concat('-', node.CacheNodeId)) === identifier; }));
        if (cluster === undefined) {
            throw new Error(`Node ${identifier} not found`);
        }
        return parseMemcachedCacheClusteWithSpecificNoderResponse(Object.assign(Object.assign({}, cluster), { nodeIdentifier: identifier }));
    });
}
//# sourceMappingURL=get-elasticache-memcached-clusters.js.map