import { z } from 'zod';
export function parseElasticacheResponse(response) {
    return response.ClusterEnabled !== undefined && response.ClusterEnabled
        ? parseElasticacheReplicationGroupCMEResponse(response)
        : parseElasticacheReplicationGroupCMDResponse(response);
}
export function parseNodeGroupMemberResponse(nodeGroupMember, replicationGroupId) {
    const Parsed = transformNodeGroupMemberResponse(nodeGroupMember);
    Parsed.replicationGroupId = replicationGroupId;
    return Parsed;
}
export function parseNodeGroupResponse(nodeGroup, replicationGroupId) {
    const Parsed = transformNodeGroupResponse(nodeGroup);
    Parsed.replicationGroupId = replicationGroupId;
    return Parsed;
}
export function parseCacheNodeResponse(cacheNode, replicationGroupId) {
    const Parsed = transformCacheNodeResponse(cacheNode);
    Parsed.replicationGroupId = replicationGroupId;
    return Parsed;
}
const transformCacheNodeResponse = z
    .object({
    CacheNodeId: z.string(),
    Endpoint: z.object({
        Address: z.string(),
        Port: z.number(),
    }),
})
    .transform(response => ({
    identifier: response.CacheNodeId,
    host: response.Endpoint.Address,
    port: response.Endpoint.Port,
    clusterMode: 'enabled',
    nodeGroups: [],
    replicationGroupId: '',
})).parse;
export const parseElasticacheReplicationGroupCMDResponse = z
    .object({
    NodeGroups: z.any(),
    ReplicationGroupId: z.string(),
})
    .transform(response => ({
    identifier: response.ReplicationGroupId,
    host: response.NodeGroups[0].PrimaryEndpoint.Address,
    port: response.NodeGroups[0].PrimaryEndpoint.Port,
    clusterMode: 'disabled',
    nodeGroups: response.NodeGroups,
    replicationGroupId: response.ReplicationGroupId,
})).parse;
export const parseElasticacheReplicationGroupCMEResponse = z
    .object({
    ReplicationGroupId: z.string(),
    ConfigurationEndpoint: z.object({
        Address: z.string(),
        Port: z.number(),
    }),
    ClusterMode: z.string(),
    NodeGroups: z.any(),
})
    .transform(response => ({
    identifier: response.ReplicationGroupId,
    host: response.ConfigurationEndpoint.Address,
    port: response.ConfigurationEndpoint.Port,
    clusterMode: response.ClusterMode,
    nodeGroups: response.NodeGroups,
    replicationGroupId: response.ReplicationGroupId,
})).parse;
export const parseElasticacheSubnetGroup = z
    .object({
    CacheSubnetGroupName: z.string(),
    VpcId: z.string(),
})
    .transform(response => ({
    name: response.CacheSubnetGroupName,
    vpcId: response.VpcId,
})).parse;
const transformNodeGroupMemberResponse = z
    .object({
    CacheClusterId: z.string(),
    ReadEndpoint: z.object({
        Address: z.string(),
        Port: z.number(),
    }),
    NodeGroups: z.any(),
})
    .transform(response => ({
    identifier: response.CacheClusterId,
    host: response.ReadEndpoint.Address,
    port: response.ReadEndpoint.Port,
    clusterMode: 'disabled',
    nodeGroups: [],
    replicationGroupId: '',
})).parse;
const transformNodeGroupResponse = z
    .object({
    NodeGroupId: z.string(),
    PrimaryEndpoint: z.object({
        Address: z.string(),
        Port: z.number(),
    }),
})
    .transform(response => ({
    identifier: response.NodeGroupId,
    host: response.PrimaryEndpoint.Address,
    port: response.PrimaryEndpoint.Port,
    clusterMode: 'disabled',
    nodeGroups: [],
    replicationGroupId: '',
})).parse;
//# sourceMappingURL=parse-elasticache-redis-response.js.map