var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { AddRoleToInstanceProfileCommand, CreateInstanceProfileCommand, waitUntilInstanceProfileExists, } from '@aws-sdk/client-iam';
import { COMMON_WAITER_CONFIG } from '../common/waiter-config.js';
import { handleWaiterError } from '../common/waiter-error.js';
import { iamClient } from './iam-client.js';
import { parseIamInstanceProfileResponse } from './parse-iam-response.js';
export function createIamInstanceProfileCurrentRegion({ name, roleNames, pathPrefix, tags, }) {
    return __awaiter(this, void 0, void 0, function* () {
        const region = yield iamClient.config.region();
        const path = `${pathPrefix}/${region}/`;
        const { InstanceProfile } = yield iamClient.send(new CreateInstanceProfileCommand({
            InstanceProfileName: name,
            Path: path,
            Tags: tags.map(tag => ({ Key: tag.key, Value: tag.value })),
        }));
        if (!InstanceProfile) {
            throw new Error(`Invalid response from AWS.`);
        }
        const instanceProfile = parseIamInstanceProfileResponse(InstanceProfile);
        yield handleWaiterError(() => __awaiter(this, void 0, void 0, function* () {
            return yield waitUntilInstanceProfileExists(Object.assign(Object.assign({}, COMMON_WAITER_CONFIG), { client: iamClient.client }), { InstanceProfileName: instanceProfile.name });
        }));
        for (const roleName of roleNames) {
            yield iamClient.send(new AddRoleToInstanceProfileCommand({
                InstanceProfileName: instanceProfile.name,
                RoleName: roleName,
            }));
        }
        return instanceProfile;
    });
}
//# sourceMappingURL=create-instance-profile.js.map