var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { DescribeDBClustersCommand } from '@aws-sdk/client-rds';
import { AwsNotFoundError } from '../common/aws-errors.js';
import { parseDbClusterResponse } from './parse-rds-response.js';
import { rdsClient } from './rds-client.js';
export function getDbClusters() {
    return __awaiter(this, void 0, void 0, function* () {
        const { DBClusters } = yield rdsClient.send(new DescribeDBClustersCommand({}));
        if (!DBClusters) {
            throw new Error(`Invalid response from AWS.`);
        }
        return DBClusters.map(cluster => parseDbClusterResponse(cluster));
    });
}
export function getDbCluster({ identifier, }) {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            const { DBClusters } = yield rdsClient.send(new DescribeDBClustersCommand({ DBClusterIdentifier: identifier }));
            if (!DBClusters) {
                throw new Error(`Invalid response from AWS.`);
            }
            return DBClusters.map(cluster => parseDbClusterResponse(cluster))[0];
        }
        catch (error) {
            if (error instanceof AwsNotFoundError) {
                return undefined;
            }
            throw error;
        }
    });
}
//# sourceMappingURL=get-db-clusters.js.map