var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { DescribeDBInstancesCommand } from '@aws-sdk/client-rds';
import { AwsNotFoundError } from '../common/aws-errors.js';
import { parseDbInstanceResponse } from './parse-rds-response.js';
import { rdsClient } from './rds-client.js';
export function getDbInstances() {
    return __awaiter(this, void 0, void 0, function* () {
        const { DBInstances } = yield rdsClient.send(new DescribeDBInstancesCommand({}));
        if (!DBInstances) {
            throw new Error(`Invalid response from AWS.`);
        }
        return DBInstances.map(instance => parseDbInstanceResponse(instance));
    });
}
export function getDbInstance({ identifier, }) {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            const { DBInstances } = yield rdsClient.send(new DescribeDBInstancesCommand({ DBInstanceIdentifier: identifier }));
            if (!DBInstances) {
                throw new Error(`Invalid response from AWS.`);
            }
            return DBInstances.map(instance => parseDbInstanceResponse(instance))[0];
        }
        catch (error) {
            if (error instanceof AwsNotFoundError) {
                return undefined;
            }
            throw error;
        }
    });
}
//# sourceMappingURL=get-db-instances.js.map