var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { RDSServiceException } from '@aws-sdk/client-rds';
import { AwsAccessDeniedError, AwsNotFoundError, AwsError, AwsTooManySecurityGroupsAttachedError, } from '../common/aws-errors.js';
export function rdsErrorHandler(operation) {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            return yield operation();
        }
        catch (error) {
            if (error instanceof RDSServiceException && error.name === 'AccessDenied') {
                throw new AwsAccessDeniedError();
            }
            if (error instanceof RDSServiceException &&
                (error.name === 'DBClusterNotFoundFault' ||
                    error.name === 'DBInstanceNotFoundFault' ||
                    error.name === 'DBSubnetGroupNotFoundFault')) {
                throw new AwsNotFoundError();
            }
            if (error instanceof RDSServiceException &&
                error.name === 'InvalidParameterCombination' &&
                error.message.toLowerCase().includes('securitygroup')) {
                throw new AwsTooManySecurityGroupsAttachedError();
            }
            if (error instanceof RDSServiceException &&
                (error.name === 'InvalidDBClusterStateFault' ||
                    error.name === 'InvalidDBInstanceStateFault')) {
                throw new AwsInvalidRdsStateError();
            }
            throw error;
        }
    });
}
export class AwsInvalidRdsStateError extends AwsError {
    constructor() {
        super(`Invalid DB state`);
    }
}
//# sourceMappingURL=rds-errors.js.map