var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { SSMServiceException } from '@aws-sdk/client-ssm';
import { AwsAccessDeniedError, AwsNotFoundError, AwsError, } from '../common/aws-errors.js';
export function ssmErrorHandler(operation) {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            return yield operation();
        }
        catch (error) {
            if (error instanceof SSMServiceException &&
                error.name === 'AccessDeniedException') {
                throw new AwsAccessDeniedError();
            }
            if (error instanceof SSMServiceException &&
                error.name === 'ParameterNotFound') {
                throw new AwsNotFoundError();
            }
            if (error instanceof SSMServiceException &&
                error.message.toLocaleLowerCase().includes('not connected')) {
                throw new AwsSsmInstanceNotConnectedError();
            }
            throw error;
        }
    });
}
export class AwsSsmInstanceNotConnectedError extends AwsError {
    constructor() {
        super('Instance is not connected to SSM');
    }
}
//# sourceMappingURL=ssm-errors.js.map