var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { ManagedResourceTypes } from '../common/resource-type.js';
import { bastionInstanceCleaner } from './bastion-instance-cleaner.js';
import { bastionInstanceProfileCleaner } from './bastion-instance-profile-cleaner.js';
import { bastionRoleCleaner } from './bastion-role-cleaner.js';
import { CLEANUP_ORDER } from './managed-resources.js';
import { accessSecurityGroupReferencesCleaner, securityGroupCleaner, } from './security-group-cleaner.js';
const RESOURCE_CLEANERS = {
    [ManagedResourceTypes.ACCESS_SECURITY_GROUP]: {
        cleaner: securityGroupCleaner,
        preparer: accessSecurityGroupReferencesCleaner,
    },
    [ManagedResourceTypes.BASTION_SECURITY_GROUP]: {
        cleaner: securityGroupCleaner,
    },
    [ManagedResourceTypes.BASTION_INSTANCE]: {
        cleaner: bastionInstanceCleaner,
    },
    [ManagedResourceTypes.BASTION_INSTANCE_PROFILE]: {
        cleaner: bastionInstanceProfileCleaner,
    },
    [ManagedResourceTypes.BASTION_ROLE]: {
        cleaner: bastionRoleCleaner,
    },
};
export function cleanupManagedResources({ managedResources, hooks, }) {
    return __awaiter(this, void 0, void 0, function* () {
        for (const resourceGroup of CLEANUP_ORDER) {
            yield cleanupResources({
                resourceGroup,
                resourceIds: managedResources[resourceGroup],
                cleaner: RESOURCE_CLEANERS[resourceGroup].cleaner,
                cleanupPreparer: RESOURCE_CLEANERS[resourceGroup].preparer,
                hooks,
            });
        }
    });
}
export function cleanupResources({ resourceGroup, resourceIds, cleaner, cleanupPreparer, hooks, }) {
    var _a, _b, _c, _d, _e, _f;
    return __awaiter(this, void 0, void 0, function* () {
        if (cleanupPreparer) {
            try {
                (_a = hooks === null || hooks === void 0 ? void 0 : hooks.onPreparingToCleanup) === null || _a === void 0 ? void 0 : _a.call(hooks, resourceGroup);
                yield cleanupPreparer(resourceIds);
                (_b = hooks === null || hooks === void 0 ? void 0 : hooks.onPreparedToCleanup) === null || _b === void 0 ? void 0 : _b.call(hooks, resourceGroup);
            }
            catch (error) {
                (_c = hooks === null || hooks === void 0 ? void 0 : hooks.onPreparationFailed) === null || _c === void 0 ? void 0 : _c.call(hooks, resourceGroup, error);
                return;
            }
        }
        for (const resourceId of resourceIds) {
            (_d = hooks === null || hooks === void 0 ? void 0 : hooks.onCleaningUpResource) === null || _d === void 0 ? void 0 : _d.call(hooks, resourceGroup, resourceId);
            try {
                yield cleaner(resourceId);
                (_e = hooks === null || hooks === void 0 ? void 0 : hooks.onResourceCleanedUp) === null || _e === void 0 ? void 0 : _e.call(hooks, resourceGroup, resourceId);
            }
            catch (error) {
                (_f = hooks === null || hooks === void 0 ? void 0 : hooks.onResourceCleanupFailed) === null || _f === void 0 ? void 0 : _f.call(hooks, resourceGroup, resourceId, error);
            }
        }
    });
}
//# sourceMappingURL=cleanup-managed-resources.js.map