var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import inquirer from 'inquirer';
import { getReplicationGroupsByClusterMode } from '#src/aws/elasticache/get-elasticache-replication-groups.js';
import { getCacheClusters } from '#src/aws/elasticache/get-elasticache-cache-clusters.js';
import { getDbClusters } from '#src/aws/rds/get-db-clusters.js';
import { getDbInstances } from '#src/aws/rds/get-db-instances.js';
import { cli } from '#src/common/cli.js';
import { fmt } from '#src/common/fmt.js';
import { getMemcachedClusters, getRawMemcachedClusters, } from '#src/aws/elasticache/get-elasticache-memcached-clusters.js';
import { getErrorDetail } from '../../error/get-error-detail.js';
import { toElasticacheChoices } from './to-elasticache-choises.js';
export function promptForAwsTarget(commandType) {
    return __awaiter(this, void 0, void 0, function* () {
        const { instances, clusters, elasticacheRedisClusters, elasticacheRedisNodes, elasticacheMemcachedClusters, elasticacheMemcachedCacheData, } = yield getTargets();
        const { target } = yield cli.prompt({
            type: 'list',
            pageSize: 20,
            name: 'target',
            message: commandType === 'init'
                ? 'Select target to initialize'
                : 'Select target to connect to',
            choices: [
                ...toRdsChoises(instances, clusters),
                ...toElasticacheChoices(elasticacheRedisClusters, elasticacheRedisNodes, elasticacheMemcachedClusters, elasticacheMemcachedCacheData, commandType),
                ...getCustomChoices(),
            ],
        });
        return target;
    });
}
function getTargets() {
    return __awaiter(this, void 0, void 0, function* () {
        const subCli = cli.createSubInstance({ indent: 2 });
        cli.out(`${fmt.green('❯')} Retrieving connection targets:`);
        const instances = yield getTargetResources(() => __awaiter(this, void 0, void 0, function* () { return yield getDbInstances(); }), 'DB instances', subCli);
        const clusters = yield getTargetResources(() => __awaiter(this, void 0, void 0, function* () { return yield getDbClusters(); }), 'DB clusters', subCli);
        const elasticacheRedisClusters = yield getTargetResources(() => __awaiter(this, void 0, void 0, function* () { return yield getReplicationGroupsByClusterMode(); }), 'Elasticache Redis clusters', subCli);
        const elasticacheRedisNodes = yield getTargetResources(() => __awaiter(this, void 0, void 0, function* () { return yield getCacheClusters(); }), 'Elasticache Redis nodes', subCli);
        const elasticacheMemcachedClusters = yield getTargetResources(() => __awaiter(this, void 0, void 0, function* () { return yield getMemcachedClusters(); }), 'Elasticache Memcached clusters', subCli);
        const elasticacheMemcachedCacheData = yield getTargetResources(() => __awaiter(this, void 0, void 0, function* () { return yield getRawMemcachedClusters(); }), 'Elasticache Memcached supplementary data', subCli);
        return {
            instances,
            clusters,
            elasticacheRedisClusters,
            elasticacheRedisNodes,
            elasticacheMemcachedClusters,
            elasticacheMemcachedCacheData,
        };
    });
}
function toRdsChoises(instances, clusters) {
    return [
        ...(instances.length > 0 || clusters.length > 0
            ? [new inquirer.Separator('RDS targets:')]
            : []),
        ...toInstanceChoices(instances),
        ...toClusterChoices(clusters),
    ];
}
function toInstanceChoices(instances) {
    if (instances.length === 0) {
        return [];
    }
    return [
        new inquirer.Separator(' Database instances:'),
        ...instances.map(instance => toInstanceChoice(instance)),
    ];
}
function toClusterChoices(clusters) {
    if (clusters.length === 0) {
        return [];
    }
    return [
        new inquirer.Separator(' Database clusters:'),
        ...clusters.map(cluster => toClusterChoice(cluster)),
    ];
}
function getCustomChoices() {
    return [
        new inquirer.Separator(),
        {
            name: 'Custom',
            value: undefined,
        },
    ];
}
function getTargetResources(getResources, resourceName, cli) {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            cli.progressStart(resourceName);
            const resources = yield getResources();
            cli.progressSuccess();
            return resources;
        }
        catch (error) {
            const warnText = getErrorDetail(error);
            cli.progressWarn({ warnText });
            return [];
        }
    });
}
function toInstanceChoice(dbInstance) {
    return {
        name: '  ' + dbInstance.identifier,
        value: {
            dbInstance,
        },
    };
}
function toClusterChoice(dbCluster) {
    return {
        name: '  ' + dbCluster.identifier,
        value: {
            dbCluster,
        },
    };
}
//# sourceMappingURL=prompt-for-aws-target.js.map