var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import * as bastionOps from '#src/bastion/ensure-bastion-running.js';
import { cli } from '#src/common/cli.js';
import { AwsNoRootVolumeAttachedError } from '#src/aws/ec2/ec2-errors.js';
import { StartingInstanceError } from '#src/bastion/bastion-errors.js';
import { OperationError } from '../../error/operation-error.js';
import { detailProvider } from '../../error/get-error-detail.js';
export function ensureBastionRunning({ bastion, }) {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            yield bastionOps.ensureBastionRunning({
                bastion,
                hooks: {
                    onWaitingInstanceToStart: () => cli.progressStart(`Bastion instance is starting. Waiting instance to start`),
                    onWaitingInstanceToStop: () => cli.progressStart(`Bastion instance is stopping. Waiting instance to stop`),
                    onWaitingInstanceToUpdate: () => cli.progressStart(`Bastion instance is updating. This may take a few minutes`),
                    onStartingInstance: () => cli.progressStart(`Bastion instance is stopped. Starting bastion instance`),
                    onInstanceStarted: () => cli.progressStop(),
                },
            });
        }
        catch (error) {
            cli.progressFailure();
            throw OperationError.fromError({
                operationName: 'Starting bastion instance',
                error,
                detailProviders: [
                    detailProvider(StartingInstanceError, error => `Can't start bastion instance ${error.instanceId}`),
                    detailProvider(AwsNoRootVolumeAttachedError, () => "Bastion instance doesn't have a volume attached at root"),
                ],
            });
        }
    });
}
//# sourceMappingURL=ensure-bastion-running.js.map