var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import * as bastionOps from '#src/bastion/get-bastion.js';
import { ManagedResourceTypes } from '#src/common/resource-type.js';
import { ResourceNotFoundError, UnexpectedStateError, } from '#src/common/runtime-errors.js';
import { OperationError } from '../../error/operation-error.js';
import { handleOperation } from '../common/handle-operation.js';
export function getBastion({ target, }) {
    return __awaiter(this, void 0, void 0, function* () {
        const bastionId = yield handleOperation('Retrieving bastion id from target', () => __awaiter(this, void 0, void 0, function* () { return yield target.getBastionId(); }));
        const bastion = yield handleOperation('Retrieving bastion', () => __awaiter(this, void 0, void 0, function* () { return yield bastionOps.getBastion({ bastionId }); }));
        if (!bastion) {
            throw OperationError.fromError({
                operationName: 'Retrieving bastion',
                error: new UnexpectedStateError(new ResourceNotFoundError(ManagedResourceTypes.BASTION_INSTANCE, bastionId)),
            });
        }
        return bastion;
    });
}
//# sourceMappingURL=get-bastion.js.map