var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { getSubnets } from '#src/aws/ec2/get-subnets.js';
import { cli } from '#src/common/cli.js';
import { fmt } from '#src/common/fmt.js';
import { EarlyExitError } from '../../error/early-exit-error.js';
import { handleOperation } from '../common/handle-operation.js';
export function selectBastionSubnetId({ vpcId, bastionSubnetInput, }) {
    return __awaiter(this, void 0, void 0, function* () {
        return bastionSubnetInput !== null && bastionSubnetInput !== void 0 ? bastionSubnetInput : (yield promptForBastionSubnetId(vpcId));
    });
}
function promptForBastionSubnetId(vpcId) {
    return __awaiter(this, void 0, void 0, function* () {
        const subnets = yield handleOperation('Retrieving VPC subnets', () => __awaiter(this, void 0, void 0, function* () { return yield getSubnets({ vpcId }); }));
        if (subnets.length === 0) {
            throw new EarlyExitError('No subnets found in the VPC. Vpc must have at least one subnet for the bastion to be set up');
        }
        const { subnet } = yield cli.prompt({
            type: 'list',
            name: 'subnet',
            message: fmt.reset('Select ') +
                fmt.important('public') +
                fmt.reset(' subnet for the bastion.') +
                fmt.gray('\n  (See docs for setting up bastion in a private subnet)'),
            choices: subnets.map(subnet => ({
                name: fmt.resourceName(subnet),
                value: subnet.id,
            })),
        });
        return subnet;
    });
}
//# sourceMappingURL=select-bastion-subnet.js.map