import { z } from 'zod';
const TargetConfigBaseParser = z.object({
    awsProfile: z.string().optional(),
    awsRegion: z.string().optional(),
});
const RdsInstanceTargetConfigParser = z
    .object({
    rdsInstance: z.string(),
})
    .merge(TargetConfigBaseParser);
const RdsClusterTargetConfigParser = z
    .object({
    rdsCluster: z.string(),
})
    .merge(TargetConfigBaseParser);
const ElasticacheRedisClusterTargetConfigParser = z
    .union([
    z
        .object({
        elasticacheRedisCluster: z.string(),
    })
        .merge(TargetConfigBaseParser),
    z
        .object({
        elasticacheCluster: z.string(),
    })
        .merge(TargetConfigBaseParser),
])
    .transform(config => {
    return 'elasticacheRedisCluster' in config
        ? config
        : Object.assign(Object.assign({}, config), { elasticacheRedisCluster: config.elasticacheCluster });
});
const ElasticacheRedisNodeTargetConfigParser = z
    .union([
    z
        .object({
        elasticacheRedisNode: z.string(),
    })
        .merge(TargetConfigBaseParser),
    z
        .object({
        elasticacheNode: z.string(),
    })
        .merge(TargetConfigBaseParser),
])
    .transform(config => {
    return 'elasticacheRedisNode' in config
        ? config
        : Object.assign(Object.assign({}, config), { elasticacheRedisNode: config.elasticacheNode });
});
const ElasticacheMemcachedClusterTargetConfigParser = z
    .object({
    elasticacheMemcachedCluster: z.string(),
})
    .merge(TargetConfigBaseParser);
const ElasticacheMemcachedNodeTargetConfigParser = z
    .object({
    elasticacheMemcachedNode: z.string(),
})
    .merge(TargetConfigBaseParser);
const CustomTargetConfigParser = z
    .object({
    customTargetVpc: z.string(),
    customTargetHost: z.string(),
    customTargetPort: z.number(),
})
    .merge(TargetConfigBaseParser);
const ConnectionTargetConfigParser = z.union([
    RdsInstanceTargetConfigParser,
    RdsClusterTargetConfigParser,
    ElasticacheRedisClusterTargetConfigParser,
    ElasticacheRedisNodeTargetConfigParser,
    ElasticacheMemcachedClusterTargetConfigParser,
    ElasticacheMemcachedNodeTargetConfigParser,
    CustomTargetConfigParser,
]);
const ConnectionConfigParser = z.object({
    target: z.union([z.string(), ConnectionTargetConfigParser]),
    localPort: z.number(),
});
export const ConfigParser = z.object({
    connections: z.record(z.string(), ConnectionConfigParser).optional(),
    targets: z.record(z.string(), ConnectionTargetConfigParser).optional(),
});
export function isRdsInstanceTargetConfig(target) {
    return 'rdsInstance' in target;
}
export function isRdsClusterTargetConfig(target) {
    return 'rdsCluster' in target;
}
export function isElasticacheRedisClusterTargetConfig(target) {
    return 'elasticacheRedisCluster' in target || 'elasticacheCluster' in target;
}
export function isElasticacheRedisNodeTargetConfig(target) {
    return 'elasticacheRedisNode' in target || 'elasticacheNode' in target;
}
export function isElasticacheMemcachedClusterTargetConfig(target) {
    return 'elasticacheMemcachedCluster' in target;
}
export function isElasticacheMemcachedNodeTargetConfig(target) {
    return 'elasticacheMemcachedNode' in target;
}
export function isCustomTargetConfig(target) {
    return 'customTargetVpc' in target;
}
//# sourceMappingURL=config-parser.js.map