var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { cosmiconfig } from 'cosmiconfig';
import { fromZodError } from 'zod-validation-error';
import { OperationError } from '../error/operation-error.js';
import { ConfigParser } from './config-parser.js';
export function getConfig() {
    return __awaiter(this, void 0, void 0, function* () {
        const configExplorer = cosmiconfig('basti', {
            searchPlaces: [
                '.basti.yaml',
                '.basti.yml',
                '.basti.json',
                'basti.yaml',
                'basti.yml',
                'basti.json',
            ],
        });
        const configResult = yield configExplorer.search();
        if (configResult === null) {
            return undefined;
        }
        return parseConfig(configResult.config);
    });
}
function parseConfig(config) {
    const result = ConfigParser.safeParse(config);
    if (result.success) {
        return result.data;
    }
    throw OperationError.fromErrorMessage({
        operationName: 'Reading configuration file',
        message: fromZodError(result.error).message,
    });
}
//# sourceMappingURL=get-config.js.map