import * as cp from 'node:child_process';
import * as readline from 'node:readline';
export class OutputOptimizedChildProcess {
    constructor(childProcess) {
        this.output = [];
        this.errorOutput = [];
        this.process = childProcess;
        this.outputLines = readline.createInterface({ input: this.process.stdout });
        this.errorOutputLines = readline.createInterface({
            input: this.process.stderr,
        });
        this.outputLines.on('line', line => this.output.push(line));
        this.errorOutputLines.on('line', line => this.errorOutput.push(line));
    }
    onLine(listener) {
        this.outputLines.on('line', listener);
        return this;
    }
    onErrorLine(listener) {
        this.errorOutputLines.on('line', listener);
        return this;
    }
    kill() {
        this.process.kill();
    }
    onExit(listener) {
        this.process.on('exit', (code, signal) => listener({
            reason: (code !== null && code !== void 0 ? code : signal),
            output: this.collectOutput(),
            errorOutput: this.collectErrorOutput(),
        }));
        return this;
    }
    collectOutput() {
        return this.output.join('\n');
    }
    collectErrorOutput() {
        return this.errorOutput.join('\n');
    }
    collectAllOutput() {
        return {
            output: this.collectOutput(),
            errorOutput: this.collectErrorOutput(),
        };
    }
}
export function spawnProcess(command, args) {
    const childProcess = cp.spawn(command, args, { stdio: 'pipe' });
    return new OutputOptimizedChildProcess(childProcess);
}
//# sourceMappingURL=child-process.js.map