var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { cli } from './cli.js';
import { getErrorMessage } from './runtime-errors.js';
const DEFAULT_CONFIG = {
    delay: 3000,
    maxRetries: 3,
    shouldRetry: () => true,
};
export function retry(action, retryConfig = {}) {
    return __awaiter(this, void 0, void 0, function* () {
        const config = Object.assign(Object.assign({}, DEFAULT_CONFIG), retryConfig);
        let retries = 0;
        do {
            try {
                return yield action();
            }
            catch (error) {
                if (retries < config.maxRetries && config.shouldRetry(error)) {
                    retries++;
                    cli.debug(`Retrying after error: ${getErrorMessage(error)}`);
                    yield delay(config.delay);
                }
                else {
                    throw error;
                }
            }
        } while (true);
    });
}
function delay(timeMs) {
    return __awaiter(this, void 0, void 0, function* () {
        return yield new Promise(resolve => setTimeout(resolve, timeMs));
    });
}
//# sourceMappingURL=retry.js.map