export function getErrorMessage(error) {
    if (error instanceof Error) {
        return error.message;
    }
    if (typeof error === 'string') {
        return error;
    }
    return '';
}
export class RuntimeError extends Error {
    constructor(message, cause) {
        super(cause !== undefined ? `${message}. ${getErrorMessage(cause)}` : message);
        this.cause = cause;
    }
    getDeepStack() {
        const thisStack = this.stack !== undefined ? this.stack : 'Error: No stack trace available';
        const causeStack = this.cause instanceof RuntimeError
            ? this.cause.getDeepStack()
            : this.cause instanceof Error
                ? this.cause.stack
                : undefined;
        return (thisStack +
            (causeStack !== undefined ? `\n\nCaused by: ${causeStack}` : ''));
    }
}
export class UnexpectedStateError extends RuntimeError {
    constructor(cause) {
        super(`Unexpected state`, cause);
    }
}
export class ResourceNotFoundError extends RuntimeError {
    constructor(resourceType, resourceId) {
        super(`Resource of type ${resourceType} with id "${resourceId !== null && resourceId !== void 0 ? resourceId : 'unknown'}" not found`);
        this.resourceType = resourceType;
        this.resourceId = resourceId;
    }
}
export class ResourceDamagedError extends RuntimeError {
    constructor(resourceType, resourceId, detail) {
        super(`${resourceType} "${resourceId}" is damaged: ${detail}`);
        this.resourceType = resourceType;
        this.resourceId = resourceId;
        this.detail = detail;
    }
}
//# sourceMappingURL=runtime-errors.js.map