var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { getSecurityGroups } from '../aws/ec2/get-security-groups.js';
import { isGroupSecurityGroupSource } from '../aws/ec2/types/aws-security-group.js';
import { BASTION_INSTANCE_NAME_PREFIX } from '../bastion/bastion.js';
import { ManagedResourceTypes } from '../common/resource-type.js';
import { ResourceDamagedError } from '../common/runtime-errors.js';
import { TargetNotInitializedError } from './target-errors.js';
import { TARGET_ACCESS_SECURITY_GROUP_NAME_PREFIX } from './target-input.js';
export class ConnectTargetBase {
    constructor({ awsClientConfig } = {}) {
        this.awsClientConfig = awsClientConfig;
    }
    isInitialized() {
        return __awaiter(this, void 0, void 0, function* () {
            const accessSecurityGroup = yield this.getAccessSecurityGroup();
            return accessSecurityGroup !== undefined;
        });
    }
    getBastionId() {
        var _a;
        return __awaiter(this, void 0, void 0, function* () {
            const accessSecurityGroup = yield this.getAccessSecurityGroup();
            if (!accessSecurityGroup) {
                throw new TargetNotInitializedError();
            }
            const sourceSecurityGroupIds = accessSecurityGroup.ingressRules
                .flatMap(rule => rule.sources)
                // eslint-disable-next-line unicorn/no-array-callback-reference -- breaks type guard usage
                .filter(isGroupSecurityGroupSource)
                .map(source => source.securityGroupId);
            const sourceSecurityGroups = yield getSecurityGroups({
                securityGroupIds: sourceSecurityGroupIds,
            });
            const bastionId = (_a = sourceSecurityGroups
                .map(group => group.name)
                .find(name => name.startsWith(BASTION_INSTANCE_NAME_PREFIX))) === null || _a === void 0 ? void 0 : _a.slice(Math.max(0, BASTION_INSTANCE_NAME_PREFIX.length + 1)); // Prefix and ID are separated with a dash.
            if (bastionId === undefined) {
                throw new ResourceDamagedError(ManagedResourceTypes.ACCESS_SECURITY_GROUP, accessSecurityGroup.id, 'No bastion security group found among the ingress rules');
            }
            return bastionId;
        });
    }
    getAccessSecurityGroup() {
        return __awaiter(this, void 0, void 0, function* () {
            const securityGroupIds = yield this.getSecurityGroupIds();
            const securityGroups = yield getSecurityGroups({ securityGroupIds });
            return securityGroups.find(group => group.name.startsWith(TARGET_ACCESS_SECURITY_GROUP_NAME_PREFIX));
        });
    }
}
//# sourceMappingURL=connect-target.js.map