var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { getCacheClusterSubnetGroup } from '#src/aws/elasticache/get-cache-cluster-subnet-group.js';
import { modifyElasticacheReplicationGroup } from '#src/aws/elasticache/modify-elasticache-clusters.js';
import { AwsError } from '#src/aws/common/aws-errors.js';
import { getDescribedreplicationGroup } from '#src/aws/elasticache/get-elasticache-replication-groups.js';
import { getDescribedCacheCluster } from '#src/aws/elasticache/get-elasticache-cache-clusters.js';
import { InitTargetBase } from '../init-target.js';
export class ElasticacheRedisClusterInitTarget extends InitTargetBase {
    constructor({ elasticacheRedisCluster, }) {
        super();
        this.elasticacheRedisCluster = elasticacheRedisCluster;
        this.detaliedInformationCluster = this.getDescribedCacheCluster();
        this.elasticacheSubnetGroupName = this.getSubnetGroupName();
        this.securityGroups = this.getSecurityGroupIds();
    }
    getId() {
        return this.elasticacheRedisCluster.identifier;
    }
    getVpcId() {
        return __awaiter(this, void 0, void 0, function* () {
            const subnetGroupName = yield this.elasticacheSubnetGroupName;
            if (subnetGroupName === undefined) {
                throw new Error(`Elasticache subnet group not found`);
            }
            const elasticacheSubnetGroup = yield getCacheClusterSubnetGroup({
                name: subnetGroupName,
            });
            if (!elasticacheSubnetGroup) {
                throw new Error(`Cluster subnet group "${subnetGroupName}" not found`);
            }
            return elasticacheSubnetGroup.vpcId;
        });
    }
    getTargetPort() {
        return this.elasticacheRedisCluster.port;
    }
    getSecurityGroupIds() {
        return __awaiter(this, void 0, void 0, function* () {
            const detailedCache = yield this.detaliedInformationCluster;
            let array = [];
            if (detailedCache.SecurityGroups !== undefined)
                array = detailedCache.SecurityGroups.map(element => {
                    return element.SecurityGroupId !== undefined
                        ? element.SecurityGroupId
                        : 'undefined';
                }).filter(str => {
                    return str !== 'undefined';
                });
            return array;
        });
    }
    getDescribedCacheCluster() {
        return __awaiter(this, void 0, void 0, function* () {
            const cluster = yield getDescribedreplicationGroup(this.elasticacheRedisCluster.identifier);
            if (cluster.NodeGroups === undefined ||
                cluster.NodeGroups[0] === undefined ||
                cluster.NodeGroups[0].NodeGroupMembers === undefined ||
                cluster.NodeGroups[0].NodeGroupMembers[0] === undefined ||
                cluster.NodeGroups[0].NodeGroupMembers[0].CacheClusterId === undefined)
                throw new AwsError('unexpected Elasticache Response');
            const cacheId = cluster.NodeGroups[0].NodeGroupMembers[0].CacheClusterId;
            return yield getDescribedCacheCluster(cacheId);
        });
    }
    getSubnetGroupName() {
        return __awaiter(this, void 0, void 0, function* () {
            const detailedCache = yield this.detaliedInformationCluster;
            return detailedCache.CacheSubnetGroupName;
        });
    }
    attachSecurityGroup(securityGroupId) {
        return __awaiter(this, void 0, void 0, function* () {
            const securityGroups = yield this.securityGroups;
            const detailedCache = yield this.detaliedInformationCluster;
            yield (this.elasticacheRedisCluster.clusterMode === 'enabled'
                ? modifyElasticacheReplicationGroup({
                    identifier: this.elasticacheRedisCluster.identifier,
                    securityGroupIds: [...securityGroups, securityGroupId],
                    cachePreviousSecurityGroups: [],
                })
                : modifyElasticacheReplicationGroup({
                    identifier: detailedCache.ReplicationGroupId,
                    securityGroupIds: [...securityGroups, securityGroupId],
                    cachePreviousSecurityGroups: [],
                }));
        });
    }
}
//# sourceMappingURL=elasticache-redis-cluster-init-target.js.map