var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { getCacheClusterSubnetGroup } from '#src/aws/elasticache/get-cache-cluster-subnet-group.js';
import { modifyElasticacheMemcachedCluster } from '#src/aws/elasticache/modify-elasticache-clusters.js';
import { InitTargetBase } from '../init-target.js';
export class ElasticacheMemcachedClusterInitTarget extends InitTargetBase {
    constructor({ elasticacheMemcachedCluster, }) {
        super();
        this.elasticacheMemcachedCluster = elasticacheMemcachedCluster;
    }
    getId() {
        return this.elasticacheMemcachedCluster.identifier;
    }
    getVpcId() {
        return __awaiter(this, void 0, void 0, function* () {
            const elasticacheSubnetGroup = yield getCacheClusterSubnetGroup({
                name: this.elasticacheMemcachedCluster.subnetGroupName,
            });
            if (!elasticacheSubnetGroup) {
                throw new Error(`Cluster subnet group "${this.elasticacheMemcachedCluster.subnetGroupName}" not found`);
            }
            return elasticacheSubnetGroup.vpcId;
        });
    }
    getTargetPort() {
        return this.elasticacheMemcachedCluster.port;
    }
    getSecurityGroupIds() {
        return __awaiter(this, void 0, void 0, function* () {
            return this.elasticacheMemcachedCluster.securityGroups;
        });
    }
    attachSecurityGroup(securityGroupId) {
        return __awaiter(this, void 0, void 0, function* () {
            yield modifyElasticacheMemcachedCluster({
                identifier: this.elasticacheMemcachedCluster.clusterId,
                securityGroupIds: [
                    ...this.elasticacheMemcachedCluster.securityGroups,
                    securityGroupId,
                ],
                cachePreviousSecurityGroups: [],
            });
        });
    }
}
//# sourceMappingURL=elasticache-memcached-cluster-init-target.js.map