var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { createSecurityGroup } from '../aws/ec2/create-security-group.js';
import { getSecurityGroups } from '../aws/ec2/get-security-groups.js';
import { generateShortId } from '../common/short-id.js';
import { AccessSecurityGroupCreationError, AccessSecurityGroupAttachmentError, } from './target-errors.js';
import { TARGET_ACCESS_SECURITY_GROUP_NAME_PREFIX } from './target-input.js';
export class InitTargetBase {
    isInitialized() {
        return __awaiter(this, void 0, void 0, function* () {
            const accessSecurityGroup = yield this.getAccessSecurityGroup();
            return accessSecurityGroup !== undefined;
        });
    }
    allowAccess({ bastion, tags, hooks, }) {
        return __awaiter(this, void 0, void 0, function* () {
            const accessSecurityGroup = yield this.createAccessSecurityGroup(bastion, tags, hooks);
            yield this.attachAccessSecurityGroup(accessSecurityGroup, hooks);
        });
    }
    getAccessSecurityGroup() {
        return __awaiter(this, void 0, void 0, function* () {
            const securityGroupIds = yield this.getSecurityGroupIds();
            const securityGroups = yield getSecurityGroups({ securityGroupIds });
            return securityGroups.find(group => group.name.startsWith(TARGET_ACCESS_SECURITY_GROUP_NAME_PREFIX));
        });
    }
    createAccessSecurityGroup(bastion, tags, hooks) {
        var _a, _b;
        return __awaiter(this, void 0, void 0, function* () {
            try {
                (_a = hooks === null || hooks === void 0 ? void 0 : hooks.onCreatingSecurityGroup) === null || _a === void 0 ? void 0 : _a.call(hooks);
                const accessSecurityGroup = yield createSecurityGroup({
                    name: `${TARGET_ACCESS_SECURITY_GROUP_NAME_PREFIX}-${generateShortId()}`,
                    description: 'Allows access from Basti instances',
                    vpcId: bastion.instance.vpcId,
                    ingressRules: [
                        {
                            ipProtocol: 'tcp',
                            sources: [
                                {
                                    securityGroupId: bastion.securityGroupId,
                                },
                            ],
                            ports: {
                                from: this.getTargetPort(),
                                to: this.getTargetPort(),
                            },
                        },
                    ],
                    tags,
                });
                (_b = hooks === null || hooks === void 0 ? void 0 : hooks.onSecurityGroupCreated) === null || _b === void 0 ? void 0 : _b.call(hooks, accessSecurityGroup.id);
                return accessSecurityGroup;
            }
            catch (error) {
                throw new AccessSecurityGroupCreationError(error);
            }
        });
    }
    attachAccessSecurityGroup(accessSecurityGroup, hooks) {
        var _a, _b;
        return __awaiter(this, void 0, void 0, function* () {
            try {
                (_a = hooks === null || hooks === void 0 ? void 0 : hooks.onAttachingSecurityGroup) === null || _a === void 0 ? void 0 : _a.call(hooks);
                yield this.attachSecurityGroup(accessSecurityGroup.id);
                (_b = hooks === null || hooks === void 0 ? void 0 : hooks.onSecurityGroupAttached) === null || _b === void 0 ? void 0 : _b.call(hooks);
            }
            catch (error) {
                throw new AccessSecurityGroupAttachmentError(error);
            }
        });
    }
}
//# sourceMappingURL=init-target.js.map