import { AwsSdkSigV4AuthInputConfig, AwsSdkSigV4AuthResolvedConfig, AwsSdkSigV4PreviouslyResolved } from "@aws-sdk/core";
import { HandlerExecutionContext, HttpAuthScheme, HttpAuthSchemeParameters, HttpAuthSchemeParametersProvider, HttpAuthSchemeProvider } from "@smithy/types";
import { ElastiCacheClientResolvedConfig } from "../ElastiCacheClient";
/**
 * @internal
 */
export interface ElastiCacheHttpAuthSchemeParameters extends HttpAuthSchemeParameters {
    region?: string;
}
/**
 * @internal
 */
export interface ElastiCacheHttpAuthSchemeParametersProvider extends HttpAuthSchemeParametersProvider<ElastiCacheClientResolvedConfig, HandlerExecutionContext, ElastiCacheHttpAuthSchemeParameters, object> {
}
/**
 * @internal
 */
export declare const defaultElastiCacheHttpAuthSchemeParametersProvider: (config: ElastiCacheClientResolvedConfig, context: HandlerExecutionContext, input: object) => Promise<ElastiCacheHttpAuthSchemeParameters>;
/**
 * @internal
 */
export interface ElastiCacheHttpAuthSchemeProvider extends HttpAuthSchemeProvider<ElastiCacheHttpAuthSchemeParameters> {
}
/**
 * @internal
 */
export declare const defaultElastiCacheHttpAuthSchemeProvider: ElastiCacheHttpAuthSchemeProvider;
/**
 * @internal
 */
export interface HttpAuthSchemeInputConfig extends AwsSdkSigV4AuthInputConfig {
    /**
     * Configuration of HttpAuthSchemes for a client which provides default identity providers and signers per auth scheme.
     * @internal
     */
    httpAuthSchemes?: HttpAuthScheme[];
    /**
     * Configuration of an HttpAuthSchemeProvider for a client which resolves which HttpAuthScheme to use.
     * @internal
     */
    httpAuthSchemeProvider?: ElastiCacheHttpAuthSchemeProvider;
}
/**
 * @internal
 */
export interface HttpAuthSchemeResolvedConfig extends AwsSdkSigV4AuthResolvedConfig {
    /**
     * Configuration of HttpAuthSchemes for a client which provides default identity providers and signers per auth scheme.
     * @internal
     */
    readonly httpAuthSchemes: HttpAuthScheme[];
    /**
     * Configuration of an HttpAuthSchemeProvider for a client which resolves which HttpAuthScheme to use.
     * @internal
     */
    readonly httpAuthSchemeProvider: ElastiCacheHttpAuthSchemeProvider;
}
/**
 * @internal
 */
export declare const resolveHttpAuthSchemeConfig: <T>(config: T & HttpAuthSchemeInputConfig & AwsSdkSigV4PreviouslyResolved) => T & HttpAuthSchemeResolvedConfig;
