import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { ElastiCacheClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../ElastiCacheClient";
import { DescribeServerlessCacheSnapshotsRequest, DescribeServerlessCacheSnapshotsResponse } from "../models/models_0";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link DescribeServerlessCacheSnapshotsCommand}.
 */
export interface DescribeServerlessCacheSnapshotsCommandInput extends DescribeServerlessCacheSnapshotsRequest {
}
/**
 * @public
 *
 * The output of {@link DescribeServerlessCacheSnapshotsCommand}.
 */
export interface DescribeServerlessCacheSnapshotsCommandOutput extends DescribeServerlessCacheSnapshotsResponse, __MetadataBearer {
}
declare const DescribeServerlessCacheSnapshotsCommand_base: {
    new (input: DescribeServerlessCacheSnapshotsCommandInput): import("@smithy/smithy-client").CommandImpl<DescribeServerlessCacheSnapshotsCommandInput, DescribeServerlessCacheSnapshotsCommandOutput, ElastiCacheClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (...[input]: [] | [DescribeServerlessCacheSnapshotsCommandInput]): import("@smithy/smithy-client").CommandImpl<DescribeServerlessCacheSnapshotsCommandInput, DescribeServerlessCacheSnapshotsCommandOutput, ElastiCacheClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Returns information about serverless cache snapshots.
 *            By default, this API lists all of the customer’s serverless cache snapshots.
 *            It can also describe a single serverless cache snapshot, or the snapshots associated with
 *            a particular serverless cache. Available for Redis OSS and Serverless Memcached only.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { ElastiCacheClient, DescribeServerlessCacheSnapshotsCommand } from "@aws-sdk/client-elasticache"; // ES Modules import
 * // const { ElastiCacheClient, DescribeServerlessCacheSnapshotsCommand } = require("@aws-sdk/client-elasticache"); // CommonJS import
 * const client = new ElastiCacheClient(config);
 * const input = { // DescribeServerlessCacheSnapshotsRequest
 *   ServerlessCacheName: "STRING_VALUE",
 *   ServerlessCacheSnapshotName: "STRING_VALUE",
 *   SnapshotType: "STRING_VALUE",
 *   NextToken: "STRING_VALUE",
 *   MaxResults: Number("int"),
 * };
 * const command = new DescribeServerlessCacheSnapshotsCommand(input);
 * const response = await client.send(command);
 * // { // DescribeServerlessCacheSnapshotsResponse
 * //   NextToken: "STRING_VALUE",
 * //   ServerlessCacheSnapshots: [ // ServerlessCacheSnapshotList
 * //     { // ServerlessCacheSnapshot
 * //       ServerlessCacheSnapshotName: "STRING_VALUE",
 * //       ARN: "STRING_VALUE",
 * //       KmsKeyId: "STRING_VALUE",
 * //       SnapshotType: "STRING_VALUE",
 * //       Status: "STRING_VALUE",
 * //       CreateTime: new Date("TIMESTAMP"),
 * //       ExpiryTime: new Date("TIMESTAMP"),
 * //       BytesUsedForCache: "STRING_VALUE",
 * //       ServerlessCacheConfiguration: { // ServerlessCacheConfiguration
 * //         ServerlessCacheName: "STRING_VALUE",
 * //         Engine: "STRING_VALUE",
 * //         MajorEngineVersion: "STRING_VALUE",
 * //       },
 * //     },
 * //   ],
 * // };
 *
 * ```
 *
 * @param DescribeServerlessCacheSnapshotsCommandInput - {@link DescribeServerlessCacheSnapshotsCommandInput}
 * @returns {@link DescribeServerlessCacheSnapshotsCommandOutput}
 * @see {@link DescribeServerlessCacheSnapshotsCommandInput} for command's `input` shape.
 * @see {@link DescribeServerlessCacheSnapshotsCommandOutput} for command's `response` shape.
 * @see {@link ElastiCacheClientResolvedConfig | config} for ElastiCacheClient's `config` shape.
 *
 * @throws {@link InvalidParameterCombinationException} (client fault)
 *  <p>Two or more incompatible parameters were specified.</p>
 *
 * @throws {@link InvalidParameterValueException} (client fault)
 *  <p>The value for a parameter is invalid.</p>
 *
 * @throws {@link ServerlessCacheNotFoundFault} (client fault)
 *  <p>The serverless cache was not found or does not exist.</p>
 *
 * @throws {@link ServerlessCacheSnapshotNotFoundFault} (client fault)
 *  <p>This serverless cache snapshot could not be found or does not exist. Available for Redis OSS and Serverless Memcached only.</p>
 *
 * @throws {@link ElastiCacheServiceException}
 * <p>Base exception class for all service exceptions from ElastiCache service.</p>
 *
 * @public
 */
export declare class DescribeServerlessCacheSnapshotsCommand extends DescribeServerlessCacheSnapshotsCommand_base {
}
